==> koshoten.net-2.2.0.tar.gz: koshoten-net/catalog/contact_us.php <==
<?php
/*
  $Id: contact_us.php,v 1.6 2006/08/07 06:21:15 ryu Exp $

  osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2003 osCommerce

  Released under the GNU General Public License
  
  modified for Koshoten.net2
  http://www.koshoten.net/
*/

  require('includes/application_top.php');

  if (defined("KN_CFG_CONTACT_BY_EMAIL") && (KN_CFG_CONTACT_BY_EMAIL == 'false')) {
    tep_redirect(tep_href_link(FILENAME_DEFAULT));
  }

  require(DIR_WS_LANGUAGES . $language . '/' . FILENAME_CONTACT_US);

  $error = false;
  $error = "";
  if (isset($HTTP_GET_VARS['action']) && ($HTTP_GET_VARS['action'] == 'confirm')) {
    if (!isset($HTTP_POST_VARS['name']) || ($HTTP_POST_VARS['name'] == '')) {
      $error = true;
      $error_msg .= ENTRY_NAME_CHECK_ERROR . "<br />";
    }
    if (!tep_validate_email(trim($HTTP_POST_VARS['email']))) {
      $error = true;
      $error_msg .= ENTRY_EMAIL_CHECK_ERROR . "<br />";
    }
  }  elseif (isset($HTTP_GET_VARS['action']) && ($HTTP_GET_VARS['action'] == 'send')) {
    if (($HTTP_POST_VARS['edit_x']) || ($HTTP_POST_VARS['edit_y'])) {
      $HTTP_GET_VARS['action'] = 'back';
    } else {
      if (isset($HTTP_POST_VARS['check']) && ($HTTP_POST_VARS['check'] == STORE_OWNER)) {
    	    $mail_contents = ENTRY_NAME . $HTTP_POST_VARS['name'] . "\n" . ENTRY_EMAIL . $HTTP_POST_VARS['email'] . "\n" . 
    	                          ENTRY_ENQUIRY . "\n" . $HTTP_POST_VARS['enquiry'];
        tep_mail(STORE_OWNER, STORE_OWNER_EMAIL_ADDRESS, EMAIL_SUBJECT, $mail_contents, $HTTP_POST_VARS['name'], $HTTP_POST_VARS['email']);
        tep_redirect(tep_href_link(FILENAME_CONTACT_US, 'action=success'));
      } else {
        $error = true;
        $error_msg .= ENTRY_EMAIL_SEND_ERROR;
      }
    }
  }

  if ($error) {
    $HTTP_GET_VARS['action'] = 'error';
  }

  $breadcrumb->add(NAVBAR_TITLE, tep_href_link(FILENAME_CONTACT_US));
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html <?php echo HTML_PARAMS; ?>>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=<?php echo CHARSET; ?>" /> 
<meta http-equiv="content-style-type" content="text/css" />
<title><?php echo TITLE; ?></title>
<base href="<?php echo (($request_type == 'SSL') ? HTTPS_SERVER : HTTP_SERVER) . DIR_WS_CATALOG; ?>" />
<link rel="stylesheet" type="text/css" href="general.css" media="screen,print" />
<link rel="stylesheet" type="text/css" href="<?php echo substr(FILENAME_CONTACT_US, 0, strrpos(FILENAME_CONTACT_US, '.'));?>.css" media="screen,print" />
</head>
<body>
<!-- header -->
<?php require(DIR_WS_INCLUDES . 'header.php'); ?>
<!-- /header -->
<hr />
<!-- contents -->
<div id="contents">
<!-- left_contents -->
<?php require(DIR_WS_INCLUDES . 'column_left.php'); ?>
<!-- /left_contents -->
<hr />
<!-- right_contents -->
<?php require(DIR_WS_INCLUDES . 'column_right.php'); ?>
<!-- /right_contents -->
<hr />
<!-- main_contents -->
<?php
  if (KN_CFG_USE_COLUMN_RIGHT == 'true') {
    if (KN_CFG_USE_COLUMN_LEFT == 'true') {
      echo '<div id="mainContentsRL">' . "\n";
    } else {
      echo '<div id="mainContentsR">' . "\n";
    }
  } else {
    if (KN_CFG_USE_COLUMN_LEFT == 'true') {
      echo '<div id="mainContentsL">' . "\n";
    } else {
      echo '<div id="mainContents">' . "\n";
    }
  }
?>
<p class="hide"><a id="skipped" name="skipped" title="<?php echo TEXT_NAVISKIPPED; ?>"><?php echo TEXT_NAVISKIPPED; ?></a></p> 
<h2 class="pageHeading"><?php echo HEADING_TITLE; ?></h2>
<div id="contactUs">
<?php
  if (isset($HTTP_GET_VARS['action']) && ($HTTP_GET_VARS['action'] == 'success')) {
    // OK
?>
<p class="successText"><?php echo TEXT_SUCCESS; ?></p>
<div class="buttonLine">
<p class="buttonRight"><a href="<?php echo tep_href_link(FILENAME_DEFAULT); ?>"><?php echo tep_image_button('button_continue.gif', IMAGE_BUTTON_CONTINUE); ?></a></p>
</div>
<?php
  } elseif (isset($HTTP_GET_VARS['action']) && ($HTTP_GET_VARS['action'] == 'confirm')) {
    // Ƴǧ
    echo tep_draw_form('contact_us', tep_href_link(FILENAME_CONTACT_US, 'action=send')) . tep_draw_hidden_field('check', STORE_OWNER) . "\n";
?>
<table>
<tr>
<th><?php echo ENTRY_NAME; ?></th>
<td><?php echo $HTTP_POST_VARS['name'] . tep_draw_hidden_field('name', $HTTP_POST_VARS['name']); ?></td>
</tr>
<tr>
<th><?php echo ENTRY_EMAIL; ?></th>
<td><?php echo $HTTP_POST_VARS['email'] . tep_draw_hidden_field('email', $HTTP_POST_VARS['email']); ?></td>
</tr>
<tr>
<th><?php echo ENTRY_ENQUIRY; ?></th>
<td><?php echo nl2br(htmlspecialchars($HTTP_POST_VARS['enquiry'])) . tep_draw_hidden_field('enquiry', $HTTP_POST_VARS['enquiry']); ?></td>
</tr>
</table>

<div class="buttonLine">
<p class="buttonLeft"><?php echo tep_image_submit('button_back.gif', IMAGE_BUTTON_BACK, 'name="edit"'); ?></p>
<p class="buttonRight"><?php echo tep_image_submit('button_continue.gif', IMAGE_BUTTON_CONTINUE); ?></p>
</div>
</form>
<?php
  } else {
    // 
    if ($HTTP_GET_VARS['action'] == 'error') {
      echo '<p class="entryError">';
      echo $error_msg;
      echo "</p>\n";
    }
    echo tep_draw_form('contact_us', tep_href_link(FILENAME_CONTACT_US, 'action=confirm')) . "\n";
?>
<table>
<tr>
<th><?php echo ENTRY_NAME; ?></th>
<td><?php echo tep_draw_input_field('name', ($HTTP_POST_VARS['name'] ? $HTTP_POST_VARS['name'] : (($language == 'japanese') ? ($last_name . ' ' . $first_name) : ($first_name . ' ' . $last_name)))); ?></td>
</tr>
<tr>
<th><?php echo ENTRY_EMAIL; ?></th>
<td><?php echo tep_draw_input_field('email', ($HTTP_POST_VARS['email'] ? $HTTP_POST_VARS['email'] : $email_address)); ?></td>
</tr>
<tr>
<th><?php echo ENTRY_ENQUIRY; ?></th>
<td><?php echo tep_draw_textarea_field('enquiry', 'soft', 50, 15, $HTTP_POST_VARS['enquiry']); ?></td>
</tr>
</table>

<div class="buttonLine">
<p class="buttonLeft"><?php echo '<a href="' . tep_href_link(FILENAME_DEFAULT) . '">' . tep_image_button('button_back.gif', IMAGE_BUTTON_BACK) . '</a>'; ?></p>
<p class="buttonRight"><?php echo tep_image_submit('button_continue.gif', IMAGE_BUTTON_CONTINUE); ?></p>
</div>
</form>
<?php
  }
?>
</div>
</div>
<!-- /main_contents -->
<hr />
<!-- footer -->
<?php require(DIR_WS_INCLUDES . 'footer.php'); ?>
<!-- /footer -->
</div>
<!-- /contents -->
</body>
</html>
<?php require(DIR_WS_INCLUDES . 'application_bottom.php'); ?>

==> koshoten.net-2.2.1.tar.gz: koshoten-net/catalog/contact_us.php <==
<?php
/*
  $Id: contact_us.php,v 1.7 2007/06/12 06:02:03 ryu Exp $

  osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2003 osCommerce

  Released under the GNU General Public License
  
  modified for Koshoten.net2
  http://www.koshoten.net/
*/

  require('includes/application_top.php');

  if (defined("KN_CFG_CONTACT_BY_EMAIL") && (KN_CFG_CONTACT_BY_EMAIL == 'false')) {
    tep_redirect(tep_href_link(FILENAME_DEFAULT));
  }

  require(DIR_WS_LANGUAGES . $language . '/' . FILENAME_CONTACT_US);

  $error = false;
  $error = "";
  if (isset($HTTP_GET_VARS['action']) && ($HTTP_GET_VARS['action'] == 'confirm')) {
    if (!isset($HTTP_POST_VARS['name']) || ($HTTP_POST_VARS['name'] == '')) {
      $error = true;
      $error_msg .= ENTRY_NAME_CHECK_ERROR . "<br />";
    }
    if (!tep_validate_email(trim($HTTP_POST_VARS['email']))) {
      $error = true;
      $error_msg .= ENTRY_EMAIL_CHECK_ERROR . "<br />";
    }
  }  elseif (isset($HTTP_GET_VARS['action']) && ($HTTP_GET_VARS['action'] == 'send')) {
    if (($HTTP_POST_VARS['edit_x']) || ($HTTP_POST_VARS['edit_y'])) {
      $HTTP_GET_VARS['action'] = 'back';
    } else {
      if (isset($HTTP_POST_VARS['check']) && ($HTTP_POST_VARS['check'] == STORE_OWNER)) {
    	    $mail_contents = ENTRY_NAME . $HTTP_POST_VARS['name'] . "\n" . ENTRY_EMAIL . $HTTP_POST_VARS['email'] . "\n" . 
    	                          ENTRY_ENQUIRY . "\n" . $HTTP_POST_VARS['enquiry'];
        tep_mail(STORE_OWNER, STORE_OWNER_EMAIL_ADDRESS, EMAIL_SUBJECT, $mail_contents, $HTTP_POST_VARS['name'], $HTTP_POST_VARS['email']);
        tep_redirect(tep_href_link(FILENAME_CONTACT_US, 'action=success'));
      } else {
        $error = true;
        $error_msg .= ENTRY_EMAIL_SEND_ERROR;
      }
    }
  }

  if ($error) {
    $HTTP_GET_VARS['action'] = 'error';
  }

  $breadcrumb->add(NAVBAR_TITLE, tep_href_link(FILENAME_CONTACT_US));
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html <?php echo HTML_PARAMS; ?>>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=<?php echo CHARSET; ?>" /> 
<meta http-equiv="content-style-type" content="text/css" />
<title><?php echo TITLE; ?></title>
<base href="<?php echo (($request_type == 'SSL') ? HTTPS_SERVER : HTTP_SERVER) . DIR_WS_CATALOG; ?>" />
<link rel="stylesheet" type="text/css" href="general.css" media="screen,print" />
<link rel="stylesheet" type="text/css" href="<?php echo substr(FILENAME_CONTACT_US, 0, strrpos(FILENAME_CONTACT_US, '.'));?>.css" media="screen,print" />
</head>
<body>
<div id="container">
<!-- header -->
<?php require(DIR_WS_INCLUDES . 'header.php'); ?>
<!-- /header -->
<hr />
<!-- contents -->
<div id="contents">
<!-- left_contents -->
<?php require(DIR_WS_INCLUDES . 'column_left.php'); ?>
<!-- /left_contents -->
<hr />
<!-- right_contents -->
<?php require(DIR_WS_INCLUDES . 'column_right.php'); ?>
<!-- /right_contents -->
<hr />
<!-- main_contents -->
<div id="mainContents">
<p class="hide"><a id="skipped" name="skipped" title="<?php echo TEXT_NAVISKIPPED; ?>"><?php echo TEXT_NAVISKIPPED; ?></a></p> 
<h2 class="pageHeading"><?php echo HEADING_TITLE; ?></h2>
<div id="contactUs">
<?php
  if (isset($HTTP_GET_VARS['action']) && ($HTTP_GET_VARS['action'] == 'success')) {
    // OK
?>
<p class="successText"><?php echo TEXT_SUCCESS; ?></p>
<div class="buttonLine">
<p class="buttonRight"><a href="<?php echo tep_href_link(FILENAME_DEFAULT); ?>"><?php echo tep_image_button('button_continue.gif', IMAGE_BUTTON_CONTINUE); ?></a></p>
</div>
<?php
  } elseif (isset($HTTP_GET_VARS['action']) && ($HTTP_GET_VARS['action'] == 'confirm')) {
    // Ƴǧ
    echo tep_draw_form('contact_us', tep_href_link(FILENAME_CONTACT_US, 'action=send')) . tep_draw_hidden_field('check', STORE_OWNER) . "\n";
?>
<table>
<tr>
<th><?php echo ENTRY_NAME; ?></th>
<td><?php echo $HTTP_POST_VARS['name'] . tep_draw_hidden_field('name', $HTTP_POST_VARS['name']); ?></td>
</tr>
<tr>
<th><?php echo ENTRY_EMAIL; ?></th>
<td><?php echo $HTTP_POST_VARS['email'] . tep_draw_hidden_field('email', $HTTP_POST_VARS['email']); ?></td>
</tr>
<tr>
<th><?php echo ENTRY_ENQUIRY; ?></th>
<td><?php echo nl2br(htmlspecialchars($HTTP_POST_VARS['enquiry'])) . tep_draw_hidden_field('enquiry', $HTTP_POST_VARS['enquiry']); ?></td>
</tr>
</table>

<div class="buttonLine">
<p class="buttonLeft"><?php echo tep_image_submit('button_back.gif', IMAGE_BUTTON_BACK, 'name="edit"'); ?></p>
<p class="buttonRight"><?php echo tep_image_submit('button_continue.gif', IMAGE_BUTTON_CONTINUE); ?></p>
</div>
</form>
<?php
  } else {
    // 
    if ($HTTP_GET_VARS['action'] == 'error') {
      echo '<p class="entryError">';
      echo $error_msg;
      echo "</p>\n";
    }
    echo tep_draw_form('contact_us', tep_href_link(FILENAME_CONTACT_US, 'action=confirm')) . "\n";
?>
<table>
<tr>
<th><?php echo ENTRY_NAME; ?></th>
<td><?php echo tep_draw_input_field('name', ($HTTP_POST_VARS['name'] ? $HTTP_POST_VARS['name'] : (($language == 'japanese') ? ($last_name . ' ' . $first_name) : ($first_name . ' ' . $last_name)))); ?></td>
</tr>
<tr>
<th><?php echo ENTRY_EMAIL; ?></th>
<td><?php echo tep_draw_input_field('email', ($HTTP_POST_VARS['email'] ? $HTTP_POST_VARS['email'] : $email_address)); ?></td>
</tr>
<tr>
<th><?php echo ENTRY_ENQUIRY; ?></th>
<td><?php echo tep_draw_textarea_field('enquiry', 'soft', 50, 15, $HTTP_POST_VARS['enquiry']); ?></td>
</tr>
</table>

<div class="buttonLine">
<p class="buttonLeft"><?php echo '<a href="' . tep_href_link(FILENAME_DEFAULT) . '">' . tep_image_button('button_back.gif', IMAGE_BUTTON_BACK) . '</a>'; ?></p>
<p class="buttonRight"><?php echo tep_image_submit('button_continue.gif', IMAGE_BUTTON_CONTINUE); ?></p>
</div>
</form>
<?php
  }
?>
</div>
</div>
<!-- /main_contents -->
</div>
<!-- /contents -->
<hr />
<!-- footer -->
<?php require(DIR_WS_INCLUDES . 'footer.php'); ?>
<!-- /footer -->
</div>
</body>
</html>
<?php require(DIR_WS_INCLUDES . 'application_bottom.php'); ?>
